==> OSCA.advanced_1.14.0.tar.gz: OSCA.advanced/inst/doc/book/index.md <==
--- 
title: "Advanced Single-Cell Analysis with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.20-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.advanced"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Ludwig Geistlinger [cre], Peter Hickey [ctb]<br/>
  **Version:** 1.14.0<br/>
  **Modified:** 2024-07-01<br/>
  **Compiled:** 2025-01-22<br/>
  **Environment:** R version 4.4.2 (2024-10-31), Bioconductor 3.20<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2025<br/>
  **Source:** https://github.com/OSCA-source/OSCA.advanced"
url: "https://github.com/OSCA-source/OSCA.advanced"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the advanced analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.20/OSCA).
This describes the more complex steps of a single-cell RNA-seq analysis ranging from doublet detection, cell cycle assignment, 
    specific steps for processing droplet data, nuclei-specific analyses, trajectory analyses, integrated analyses with protein abundances, and interactive visualization. It also elaborates on some of the basic analysis steps, focusing on alternative strategies and theoretical considerations. It is intended for readers who are already familiar with basic single-cell analyses, possibly after reading some of the prior books in this collection.

==> OSCA.advanced_1.16.0.tar.gz: OSCA.advanced/inst/doc/book/index.md <==
--- 
title: "Advanced Single-Cell Analysis with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.21-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.advanced"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Ludwig Geistlinger [cre], Peter Hickey [ctb]<br/>
  **Version:** 1.16.0<br/>
  **Modified:** 2025-03-31<br/>
  **Compiled:** 2025-04-16<br/>
  **Environment:** R version 4.5.0 RC (2025-04-04 r88126), Bioconductor 3.21<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2025<br/>
  **Source:** https://github.com/OSCA-source/OSCA.advanced"
url: "https://github.com/OSCA-source/OSCA.advanced"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the advanced analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.21/OSCA).
This describes the more complex steps of a single-cell RNA-seq analysis ranging from doublet detection, cell cycle assignment, 
    specific steps for processing droplet data, nuclei-specific analyses, trajectory analyses, integrated analyses with protein abundances, and interactive visualization. It also elaborates on some of the basic analysis steps, focusing on alternative strategies and theoretical considerations. It is intended for readers who are already familiar with basic single-cell analyses, possibly after reading some of the prior books in this collection.
